@@ -9,8 +9,11 @@ class PyTwoFaas():
     print self.cToken
 
   def init(self, clientId, phoneNum):
+    print "It got here"
     payload = { 'userID' : clientId, 'compTK': self.cToken, 'userNum': phoneNum }
+    print "Here"
     r = requests.post(self.url + "/init", data=payload)
+    print "There"
     print(r.text)
 
   def validate(self, clientId, code):
